summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kbudgetview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kbudgetview.h')
-rw-r--r--kmymoney2/views/kbudgetview.h37
1 files changed, 19 insertions, 18 deletions
diff --git a/kmymoney2/views/kbudgetview.h b/kmymoney2/views/kbudgetview.h
index f857a15..14c7611 100644
--- a/kmymoney2/views/kbudgetview.h
+++ b/kmymoney2/views/kbudgetview.h
@@ -21,7 +21,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qwidget.h>
+#include <tqwidget.h>
// ----------------------------------------------------------------------------
// KDE Includes
@@ -50,20 +50,20 @@ public:
/**
* Constructor to be used to construct a budget entry object.
*
* @param parent pointer to the KListView object this entry should be
* added to.
* @param budget const reference to MyMoneyBudget for which
* the KListView entry is constructed
*/
- KBudgetListItem(KListView *parent, const MyMoneyBudget& budget);
+ KBudgetListItem(KListView *tqparent, const MyMoneyBudget& budget);
~KBudgetListItem();
/**
* This method is re-implemented from QListViewItem::paintCell().
* Besides the standard implementation, the QPainter is set
* according to the applications settings.
*/
- void paintCell(QPainter *p, const QColorGroup & cg, int column, int width, int align);
+ void paintCell(TQPainter *p, const TQColorGroup & cg, int column, int width, int align);
const MyMoneyBudget& budget(void) { return m_budget; };
void setBudget(const MyMoneyBudget& budget) { m_budget = budget; }
@@ -79,14 +79,15 @@ private:
class KBudgetView : public KBudgetViewDecl
{
Q_OBJECT
+ TQ_OBJECT
public:
- KBudgetView(QWidget *parent=0, const char *name=0);
+ KBudgetView(TQWidget *tqparent=0, const char *name=0);
~KBudgetView();
void show();
/**
- * Override the base class behaviour to restore the layout. Do not
- * do this in show() because show() itself may change the layout
+ * Override the base class behaviour to restore the tqlayout. Do not
+ * do this in show() because show() itself may change the tqlayout
* in undesired ways.
*/
void polish(void);
@@ -123,16 +124,16 @@ public slots:
protected:
- void resizeEvent(QResizeEvent*);
+ void resizeEvent(TQResizeEvent*);
void loadAccounts(void);
- bool loadSubAccounts(KMyMoneyAccountTreeBudgetItem* parent, QStringList& accountList, const MyMoneyBudget& budget);
+ bool loadSubAccounts(KMyMoneyAccountTreeBudgetItem* tqparent, TQStringList& accountList, const MyMoneyBudget& budget);
/**
* This method loads all available budgets into the budget list widget. If a budget is
* currently selected it remains selected if it is still present.
*/
void loadBudgets(void);
- void ensureBudgetVisible(const QString& id);
+ void ensureBudgetVisible(const TQString& id);
const MyMoneyBudget& selectedBudget(void) const;
KMyMoneyAccountTreeBudgetItem* selectedAccount(void) const;
void setTimeSpan(KMyMoneyAccountTreeBudgetItem *account, MyMoneyBudget::AccountGroup& accountGroup, int iTimeSpan);
@@ -148,7 +149,7 @@ protected slots:
* @param col The column where the name is located
* @param txt The text of the new name
*/
- void slotRenameBudget(QListViewItem *p, int col, const QString& txt);
+ void slotRenameBudget(TQListViewItem *p, int col, const TQString& txt);
/**
* This slot is called when the amount of a budget is changed. It
@@ -158,7 +159,7 @@ protected slots:
/**
*/
- void slotSelectAccount(QListViewItem*);
+ void slotSelectAccount(TQListViewItem*);
void AccountEnter();
@@ -181,14 +182,14 @@ private slots:
* @param i the item on which the cursor resides
* @param p position of the pointing device
*/
- void slotOpenContextMenu(KListView* lv, QListViewItem* i, const QPoint& p);
+ void slotOpenContextMenu(KListView* lv, TQListViewItem* i, const TQPoint& p);
signals:
/**
* This signal serves as proxy for KMyMoneyBudgetList::selectObject()
*/
void openContextMenu(const MyMoneyObject& obj);
- void selectObjects(const QValueList<MyMoneyBudget>& budget);
+ void selectObjects(const TQValueList<MyMoneyBudget>& budget);
private:
typedef enum {
@@ -200,8 +201,8 @@ private:
MyMoneyBudget m_budget;
- QMap<QString, unsigned long> m_transactionCountMap;
- QStringList m_yearList;
+ TQMap<TQString, unsigned long> m_transactionCountMap;
+ TQStringList m_yearList;
KMyMoneyAccountTreeBudgetItem* m_incomeItem;
KMyMoneyAccountTreeBudgetItem* m_expenseItem;
@@ -50,20 +50,20 @@ public:
* Constructor to be used to construct a budget entry object.
*
- * @param parent pointer to the KListView object this entry should be
+ * @param tqparent pointer to the KListView object this entry should be
* added to.
* @param budget const reference to MyMoneyBudget for which
@@ -50,20 +50,20 @@ public:
~KBudgetListItem();
/**
- * This method is re-implemented from QListViewItem::paintCell().
- * Besides the standard implementation, the QPainter is set
+ * This method is re-implemented from TQListViewItem::paintCell().
+ * Besides the standard implementation, the TQPainter is set
* according to the applications settings.
*/